#This script corresponds to the following article
#Anion exchange capacity explains deep soil nitrate accumulation in Brazilian Amazon croplands
#Alexandra Huddell, Christopher Neill, Cheryl A. Palm, Darlisson Nunes, and Duncan N. L. Menge


#set working directory and load libaries 
setwd('') #set to the appropriate working directory containing the dat file
library(tidyverse)
library(ggplot2)
library(patchwork)
library(lmerTest)

dat <-read.csv(
    'Tanguro soil texture for github.csv',
    header = T,
    stringsAsFactors = F)

dat$depth_num <-
  as.factor(dat$depth_num) #converting the depth number column to factor
levels(dat$depth_num) #checking levels

#summary stats of the texutre measurement
texture_summary <- dat %>%
  summarize(
    min_pct_clay= min(pct_clay, na.rm = T),
    max_pct_clay= max(pct_clay, na.rm = T),
    mean_pct_clay = mean(pct_clay, na.rm = T),
    sd_pct_clay = sd(pct_clay, na.rm = T),
    mean_pct_silt = mean(pct_silt, na.rm = T),
    sd_pct_silt = sd(pct_clay, na.rm = T),
    mean_pct_sand = mean(pct_sand, na.rm = T),
    sd_pct_sand = sd(pct_sand, na.rm = T)
  )
texture_summary

#summarizing data by particle size
clay_table<- dat %>%
  group_by(depth_num, treatment) %>%
  summarise(mean_clay = mean(pct_clay, na.rm = T),
            sd_clay = sd(pct_clay, na.rm = T))
clay_table

clay_table %>% pivot_wider(names_from = treatment,
                           values_from = c(mean_clay,sd_clay))

silt_table<- dat %>%
  group_by(depth_num, treatment) %>%
  summarise(mean_silt = mean(pct_silt, na.rm = T),
            sd_silt = sd(pct_silt, na.rm = T))
silt_table

silt_table %>% pivot_wider(names_from = treatment,
                           values_from = c(mean_silt,sd_silt))

sand_table<- dat %>%
  group_by(depth_num, treatment) %>%
  summarise(mean_sand = mean(pct_sand, na.rm = T),
            sd_sand = sd(pct_sand, na.rm = T))
sand_table

sand_table %>% pivot_wider(names_from = treatment,
                           values_from = c(mean_sand,sd_sand))



#separating data by each depth
dat1 <- dat[dat$depth_num == '1',]
dat2 <- dat[dat$depth_num == '2',]
dat3 <- dat[dat$depth_num == '3',]
dat4 <- dat[dat$depth_num == '4',]
dat5 <- dat[dat$depth_num == '5',]
dat6 <- dat[dat$depth_num == '6',]
dat7 <- dat[dat$depth_num == '7',]
dat8 <- dat[dat$depth_num == '8',]


#ANOVA within each depth for % clay

dat1_narm <- na.omit(dat1)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat1_narm)))

dat2_narm <- na.omit(dat2)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat2_narm)))

dat3_narm <- na.omit(dat3)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat3_narm)))

dat4_narm <- na.omit(dat4)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat4_narm)))

dat5_narm <- na.omit(dat5)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat5_narm)))

dat6_narm <- na.omit(dat6)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat6_narm)))

dat7_narm <- na.omit(dat7)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat7_narm)))

dat8_narm <- na.omit(dat8)
summary(aov(lm(pct_clay ~ as.factor(treatment), data = dat8_narm)))


#ANOVA within each depth for % silt
dat1_narm <- na.omit(dat1)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat1_narm)))

dat2_narm <- na.omit(dat2)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat2_narm)))

dat3_narm <- na.omit(dat3)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat3_narm)))

dat4_narm <- na.omit(dat4)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat4_narm)))

dat5_narm <- na.omit(dat5)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat5_narm)))

dat6_narm <- na.omit(dat6)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat6_narm)))

dat7_narm <- na.omit(dat7)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat7_narm)))

dat8_narm <- na.omit(dat8)
summary(aov(lm(pct_silt ~ as.factor(treatment), data = dat8_narm)))


#ANOVA within each depth for sand
dat1_narm <- na.omit(dat1)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat1_narm)))

dat2_narm <- na.omit(dat2)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat2_narm)))

dat3_narm <- na.omit(dat3)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat3_narm)))

dat4_narm <- na.omit(dat4)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat4_narm)))

dat5_narm <- na.omit(dat5)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat5_narm)))

dat6_narm <- na.omit(dat6)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat6_narm)))

dat7_narm <- na.omit(dat7)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat7_narm)))

dat8_narm <- na.omit(dat8)
summary(aov(lm(pct_sand ~ as.factor(treatment), data = dat8_narm)))

